==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANewExpression.h <==
// public final class soot.jimple.parser.node.ANewExpression

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 26ff46b3ee8d6378 soot_jimple_parser_node_ANewExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_ANewExpression_H_
#define _JC_soot_jimple_parser_node_ANewExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNewExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANewExpression$sub_refs	_jc_soot_jimple_parser_node_ANewExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs	_jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$refs	_jc_soot_jimple_parser_node_ANewExpression$refs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$nonrefs	_jc_soot_jimple_parser_node_ANewExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$object	_jc_soot_jimple_parser_node_ANewExpression$object;

typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vmethods	_jc_soot_jimple_parser_node_ANewExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vtable	_jc_soot_jimple_parser_node_ANewExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vtype	_jc_soot_jimple_parser_node_ANewExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANewExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
extern void _jc_soot_jimple_parser_node_ANewExpression$method$_init$9af5e870d7655c3e(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANewExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANewExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
extern struct _jc_soot_jimple_parser_node_PNewExpr$object *_jc_soot_jimple_parser_node_ANewExpression$method$getNewExpr$95cd2bbd79fb44b7(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
extern void _jc_soot_jimple_parser_node_ANewExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANewExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANewExpression$method$setNewExpr$56209e2e4338d22a(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANewExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$getNewExpr$95cd2bbd79fb44b7;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$setNewExpr$56209e2e4338d22a;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANewExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
	struct _jc_soot_jimple_parser_node_PNewExpr$object	*(*getNewExpr$95cd2bbd79fb44b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNewExpr$56209e2e4338d22a)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANewExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_ANewExpression$vmethods	soot_jimple_parser_node_ANewExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANewExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANewExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANewExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PNewExpr$object	*__5fnewExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANewExpression$refs {
    _jc_soot_jimple_parser_node_ANewExpression$sub_refs	soot_jimple_parser_node_ANewExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANewExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs	soot_jimple_parser_node_ANewExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANewExpression$object {
	_jc_soot_jimple_parser_node_ANewExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANewExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANewExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANewExpression$vtype _jc_soot_jimple_parser_node_ANewExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANewExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANewExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANewExpression_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANewExpression.h <==
// public final class soot.jimple.parser.node.ANewExpression

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 26ff46b3ee8d6378 soot_jimple_parser_node_ANewExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_ANewExpression_H_
#define _JC_soot_jimple_parser_node_ANewExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNewExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANewExpression$sub_refs	_jc_soot_jimple_parser_node_ANewExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs	_jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$refs	_jc_soot_jimple_parser_node_ANewExpression$refs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$nonrefs	_jc_soot_jimple_parser_node_ANewExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANewExpression$object	_jc_soot_jimple_parser_node_ANewExpression$object;

typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vmethods	_jc_soot_jimple_parser_node_ANewExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vtable	_jc_soot_jimple_parser_node_ANewExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANewExpression$vtype	_jc_soot_jimple_parser_node_ANewExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANewExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANewExpression$method$_init$9af5e870d7655c3e(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANewExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANewExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PNewExpr$object *_jc_soot_jimple_parser_node_ANewExpression$method$getNewExpr$95cd2bbd79fb44b7(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANewExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANewExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANewExpression$method$setNewExpr$56209e2e4338d22a(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANewExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$getNewExpr$95cd2bbd79fb44b7;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$setNewExpr$56209e2e4338d22a;
extern _jc_method _jc_soot_jimple_parser_node_ANewExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANewExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PNewExpr$object	*(*getNewExpr$95cd2bbd79fb44b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNewExpr$56209e2e4338d22a)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *, struct _jc_soot_jimple_parser_node_PNewExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANewExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANewExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_ANewExpression$vmethods	soot_jimple_parser_node_ANewExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANewExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANewExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANewExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PNewExpr$object	*__5fnewExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANewExpression$refs {
    _jc_soot_jimple_parser_node_ANewExpression$sub_refs	soot_jimple_parser_node_ANewExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANewExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_ANewExpression$sub_nonrefs	soot_jimple_parser_node_ANewExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANewExpression$object {
	_jc_soot_jimple_parser_node_ANewExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANewExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANewExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANewExpression$vtype _jc_soot_jimple_parser_node_ANewExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANewExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANewExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANewExpression_H_ */
